@@ -4,13 +4,13 @@ from __future__ import absolute_import, print_function
 import logging
 import warnings
 
-from vistir.compat import ResourceWarning
+import setuptools
 
 from .models.lockfile import Lockfile
 from .models.pipfile import Pipfile
 from .models.requirements import Requirement
 
-__version__ = "1.5.15"
+__version__ = "1.6.2"
 
 
 logger = logging.getLogger(__name__)
